pub struct TrackedStorageKey {
pub key: Vec<u8>,
pub has_been_read: bool,
pub has_been_written: bool,
}Expand description
Storage key with read/write tracking information.
Fields
key: Vec<u8>has_been_read: boolhas_been_written: boolTrait Implementations
Sourceimpl Clone for TrackedStorageKey
impl Clone for TrackedStorageKey
Sourcefn clone(&self) -> TrackedStorageKey
fn clone(&self) -> TrackedStorageKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackedStorageKey
impl Debug for TrackedStorageKey
Sourceimpl Decode for TrackedStorageKey
impl Decode for TrackedStorageKey
Sourceimpl Encode for TrackedStorageKey
impl Encode for TrackedStorageKey
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for TrackedStorageKey
impl Eq for TrackedStorageKey
Sourceimpl Hash for TrackedStorageKey
impl Hash for TrackedStorageKey
Sourceimpl Ord for TrackedStorageKey
impl Ord for TrackedStorageKey
Sourcefn cmp(&self, other: &TrackedStorageKey) -> Ordering
fn cmp(&self, other: &TrackedStorageKey) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackedStorageKey
impl PartialEq for TrackedStorageKey
Sourceimpl PartialOrd for TrackedStorageKey
impl PartialOrd for TrackedStorageKey
impl StructuralPartialEq for TrackedStorageKey